@@ -147,6 +147,8 @@ command.add(nil, {
   end,
 
   ["core:change-project-folder"] = function()
+    local dirname = common.dirname(core.project_dir)
+    core.command_view:set_text(dirname .. PATHSEP)
     core.command_view:enter("Change Project Folder", function(text, item)
       text = system.absolute_path(common.home_expand(item and item.text or text))
       if text == core.project_dir then return end
